<template>
  <view class="list_box">
    <z-paging
      ref="pagingRef"
      v-model="cardList"
      :fixed="false"
      :auto-show-back-to-top="true"
      @query="getList"
    >
      <template #top>
        <CardTitle title="单丝领用" :hideAction="false">
          <template #action>
            <wd-button type="icon" icon="scan" color="#0D867F" @click="openScan"></wd-button>
          </template>
        </CardTitle>
      </template>
      <MonofilCard v-for="(item, index) in cardList" v-model:value="item" :key="index" />
      <template #bottom>
        <view class="flex justify-center items-center">
          <wd-button block>
            <text class="text-[#fff]" @click="save">保存</text>
          </wd-button>
        </view>
      </template>
    </z-paging>
  </view>
  <Scan ref="scanRef" />
</template>

<script setup lang="ts">
import CardTitle from "@/components/card-title/index.vue";
import MonofilCard from "../components/MonofilCard.vue";
import { onLoad, onUnload, onShow, onHide } from "@dcloudio/uni-app";
import Scan from "@/components/scan/index.vue";
import ManageApi from "@/api/product/manage";
import TwistApi from "@/api/product/twist";
import zPaging from "@/components/z-paging/z-paging.vue";
import { useMessage } from "wot-design-uni";
// import { useZebraScan } from "@/hooks/useZebraScan";
// const { init, start, stop, triggerScan } = useZebraScan();

const paramsId = ref();
const pagingRef = ref();
const scanRef = ref();
const cardList = ref<any[]>([]);
const message = useMessage();

const getScanCode = async (code: any) => {
  console.log("自定义扫描的结果回调函数:", code);
  // let parseData = code.trim();
  let codeArr = code.code.split(",");
  console.log("sb:", codeArr);
  const { data } = await TwistApi.getScarn({
    outPutId: codeArr[1],
  });
  // console.log("单丝编号", data);
  // message.alert({
  //   title: "单丝编号",
  //   msg: JSON.stringify(data),
  // });
  pagingRef.value.complete([data]);
};

const openScan = () => {
  scanRef.value.triggerScan();
};

const getList = async () => {
  const { code, data } = await ManageApi.getStrandedWireDish({
    wireId: paramsId.value,
    type: "单丝",
  });
  if (code == 200) {
    pagingRef.value.complete(data);
  }
};

const save = () => {};

onLoad((options: any) => {
  // 开启广播监听事件
  uni.$on("scan", getScanCode);
  paramsId.value = options.id;
});
onUnload(() => {
  // 开启广播监听事件
  uni.$off("scan", getScanCode);
});

onShow(() => {});

onHide(() => {});
</script>

<style lang="scss" scoped>
.list_box {
  height: calc(100vh - 100px);
  background: #f3f9f8;
}
:deep(.wd-button__content) {
  color: #0d867f;
}
</style>
